==> odoo_14.0.0+dfsg.3.orig.tar.xz: odoo-14.0.0+dfsg.3/addons/note/README.md <==
Odoo Notes
----------

Organize yourself with efficient <a href="https://www.odoo.com/page/notes">todo lists and notes</a>.
From personal tasks to collaborative meeting minutes, increase your user's
productivity by giving them the tools to prioritize their work, share their
ideas and collaborate on documents.

Personal to-do lists that works
-------------------------------

Quickly create to-dos, organize horizontally for the mid-term (today, this week, this month, ...), prioritize vertically for the short term and group by assigning colors. The kanban approach allows a simple visual organization of your to-dos.

### Beat Work Overload

Feel how good it is to rely on a structured way to organize your work instead of keeping everything in memory. Use notes to [Get Things Done](http://en.wikipedia.org/wiki/Getting_Things_Done).

### Prioritize Efficiently

Most people are lost in the flow of urgent daily tasks and have difficulties to work on important, long-term tasks. Notes gives you a simple way to allocate time very day to do important, but less urgent tasks.

### Find Motivation to Close Tasks

People used to work on tasks they like and not on important tasks. Start feeling good by checking tasks as done.

Adapts to Your Creative Process
-------------------------------

### Customize to your own workflow

Everyone has their own way to organize activities. Odoo Notes' smart kanban approach allows every user to customize their own steps to process it's to-dos and notes.

### A Creative Person

A creative person will organize notes based on idea's maturity level: Draft Ideas ** Mature Ideas ** Specified **To Do

### A Frequent Traveler

An employee travelling a lot can organize their tasks based on the context to perform the task: U.S. Office | London's Office | To Review during Flights | At Home

### A Manager

A manager will organize their high number of tasks based on prioritizations: Todo Today | This Week | This Month | Later

Personnal Notes
---------------

### Notes are private but can be shared

Write down your ideas in pads, keep your notes at your finger tips, attach related documents and use tags and colors to organize the information. Once your ideas are mature, you can share them to others users, start discussing it and collaborate by improving the specification in the pad.

Collaborative Meeting Minutes
-----------------------------

### Real-time sharing and editing of notes

The real time collaborative writings on notes makes it the perfect tool to collaborate on meeting minutes. Attendees will be able to contribute to the minutes, attach important documents or discuss on the related thread.

==> odoo_16.0.0+dfsg.2.orig.tar.xz: odoo-16.0.0+dfsg.2/addons/note/README.md <==
Odoo Notes
----------

Organize yourself with efficient <a href="https://www.odoo.com/app/notes">todo lists and notes</a>.
From personal tasks to collaborative meeting minutes, increase your user's
productivity by giving them the tools to prioritize their work, share their
ideas and collaborate on documents.

Personal to-do lists that works
-------------------------------

Quickly create to-dos, organize horizontally for the mid-term (today, this week, this month, ...), prioritize vertically for the short term and group by assigning colors. The kanban approach allows a simple visual organization of your to-dos.

### Beat Work Overload

Feel how good it is to rely on a structured way to organize your work instead of keeping everything in memory. Use notes to [Get Things Done](http://en.wikipedia.org/wiki/Getting_Things_Done).

### Prioritize Efficiently

Most people are lost in the flow of urgent daily tasks and have difficulties to work on important, long-term tasks. Notes gives you a simple way to allocate time very day to do important, but less urgent tasks.

### Find Motivation to Close Tasks

People used to work on tasks they like and not on important tasks. Start feeling good by checking tasks as done.

Adapts to Your Creative Process
-------------------------------

### Customize to your own workflow

Everyone has their own way to organize activities. Odoo Notes' smart kanban approach allows every user to customize their own steps to process it's to-dos and notes.

### A Creative Person

A creative person will organize notes based on idea's maturity level: Draft Ideas ** Mature Ideas ** Specified **To Do

### A Frequent Traveler

An employee travelling a lot can organize their tasks based on the context to perform the task: U.S. Office | London's Office | To Review during Flights | At Home

### A Manager

A manager will organize their high number of tasks based on prioritizations: Todo Today | This Week | This Month | Later

Personnal Notes
---------------

### Notes are private but can be shared

Write down your ideas in pads, keep your notes at your finger tips, attach related documents and use tags and colors to organize the information. Once your ideas are mature, you can share them to others users, start discussing it and collaborate by improving the specification in the pad.

Collaborative Meeting Minutes
-----------------------------

### Real-time sharing and editing of notes

The real time collaborative writings on notes makes it the perfect tool to collaborate on meeting minutes. Attendees will be able to contribute to the minutes, attach important documents or discuss on the related thread.
